==> haskell-here-1.2.13-222-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-here.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 here
version:              1.2.13
visibility:           public
id:                   here-1.2.13-3xoJwiziPxc5uDdo9v3n6F
key:                  here-1.2.13-3xoJwiziPxc5uDdo9v3n6F
license:              BSD-3-Clause
copyright:            ©2013 Taylor M. Hedberg, ©2014 Google Inc.
maintainer:           t@tmh.cc
author:               Taylor M. Hedberg
homepage:             https://github.com/tmhedberg/here
synopsis:             Here docs & interpolated strings via quasiquotation
description:          Here docs & interpolated strings via quasiquotation
category:             Data
abi:                  718793a361651d290353f2a1ec4e9bf8
exposed:              True
exposed-modules:
    Data.String.Here Data.String.Here.Interpolated
    Data.String.Here.Uninterpolated

hidden-modules:       Data.String.Here.Internal
import-dirs:          /usr/lib/ghc-8.10.4/site-local/here-1.2.13
library-dirs:         /usr/lib/ghc-8.10.4/site-local/here-1.2.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/here-1.2.13
hs-libraries:         HShere-1.2.13-3xoJwiziPxc5uDdo9v3n6F
depends:
    base-4.14.1.0 haskell-src-meta-0.8.7-8EiX5TkfEmP6BPjpWIFa3i
    mtl-2.2.2 parsec-3.1.14.0 template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-here/html/here.haddock
haddock-html:         /usr/share/doc/haskell-here/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-here-1.2.13-224-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-here.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 here
version:              1.2.13
visibility:           public
id:                   here-1.2.13-DGjfNGqAOK63wuGOnOV6K2
key:                  here-1.2.13-DGjfNGqAOK63wuGOnOV6K2
license:              BSD-3-Clause
copyright:            ©2013 Taylor M. Hedberg, ©2014 Google Inc.
maintainer:           t@tmh.cc
author:               Taylor M. Hedberg
homepage:             https://github.com/tmhedberg/here
synopsis:             Here docs & interpolated strings via quasiquotation
description:          Here docs & interpolated strings via quasiquotation
category:             Data
abi:                  5bed3e87f2e5d969fa13fdd8095d1061
exposed:              True
exposed-modules:
    Data.String.Here Data.String.Here.Interpolated
    Data.String.Here.Uninterpolated

hidden-modules:       Data.String.Here.Internal
import-dirs:          /usr/lib/ghc-8.10.4/site-local/here-1.2.13
library-dirs:         /usr/lib/ghc-8.10.4/site-local/here-1.2.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/here-1.2.13
hs-libraries:         HShere-1.2.13-DGjfNGqAOK63wuGOnOV6K2
depends:
    base-4.14.1.0 haskell-src-meta-0.8.7-9F1DcOQ6wTJ9zRPE2H3Vtj
    mtl-2.2.2 parsec-3.1.14.0 template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-here/html/here.haddock
haddock-html:         /usr/share/doc/haskell-here/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
